@@ -1,10 +1,12 @@
 package LWP::Protocol::ftp;
-$LWP::Protocol::ftp::VERSION = '6.30';
+
 # Implementation of the ftp protocol (RFC 959). We let the Net::FTP
 # package do all the dirty work.
 use base qw(LWP::Protocol);
 use strict;
 
+our $VERSION = '6.31';
+
 use Carp            ();
 use HTTP::Status    ();
 use HTTP::Negotiate ();
@@ -15,9 +17,10 @@ use File::Listing   ();
 
 {
 
-    package LWP::Protocol::MyFTP;
-$LWP::Protocol::MyFTP::VERSION = '6.30';
-use strict;
+    package # hide from PAUSE
+        LWP::Protocol::MyFTP;
+
+    use strict;
     use base qw(Net::FTP);
 
     sub new {
